// $Id: TIFFExporter.java 13934 2011-10-03 09:43:41Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.*;
import javax.swing.*;
import javax.swing.filechooser.FileFilter;
import java.util.*;
import java.awt.*;
import java.awt.image.*;
import java.io.*;

/**
 * A subclass of {@link Exporter} that handles saving a PDF as
 * a TIFF file.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">TIFFExporter</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.10.2
 */
public class TIFFExporter extends Exporter
{
    private FileFilter filefilter;

    public TIFFExporter() {
        super("TIFFExporter");
        filefilter = new FileFilter() {
            public boolean accept(File file) {
                return file.isDirectory() || file.getName().toLowerCase().endsWith(".tif") || file.getName().toLowerCase().endsWith(".tiff");
            }
            public String getDescription() {
                return UIManager.getString("PDFViewer.FilesTIFF");
            }
        };
    }

    public FileFilter getFileFilter() {
        return filefilter;
    }

    public String getFileSuffix() {
        return "tif";
    }

    public JComponent getComponent() {
        return new TIFFComponent();
    }

    public ExporterTask getExporter(final DocumentPanel panel, final PDF pdf, final JComponent c, final OutputStream out) {
        return new ExporterTask() {
            private PDFParser parser;
            public final boolean isCancellable() {
                return true;
            }
            public float getProgress() {
                return parser == null ? 0 : parser.getWriteAsTIFFProgress();
            }
            public void savePDF() throws IOException {
                TIFFComponent tc = (TIFFComponent)c;
                parser = new PDFParser(pdf);
                parser.writeAsTIFF(out, tc.getDPI(), tc.getSelectedColorModel());
                out.close();
            }
        };
    }


    private static class TIFFComponent extends JPanel {
        private JComboBox dpi;
        private JComboBox colormodel;

        TIFFComponent() {
            super(new GridBagLayout());
            dpi = new JComboBox(new String[] { "72", "100", "150", "200", "300", "400", "600" });
            colormodel = new JComboBox(new String[] { UIManager.getString("PDFViewer.export.RGB"), UIManager.getString("PDFViewer.export.Gray"), UIManager.getString("PDFViewer.export.BW") });

            GridBagConstraints gbc = new GridBagConstraints();
            gbc.fill = gbc.HORIZONTAL;
            gbc.gridwidth = 1;
            add(new JLabel(UIManager.getString("PDFViewer.export.DPI")), gbc);
            gbc.gridwidth = gbc.REMAINDER;
            add(dpi, gbc);
            gbc.gridwidth = 1;
            add(new JLabel(UIManager.getString("PDFViewer.export.ColorModel")), gbc);
            gbc.gridwidth = gbc.REMAINDER;
            add(colormodel, gbc);
        }

        int getDPI() {
            return Integer.parseInt(dpi.getSelectedItem().toString());
        }

        ColorModel getSelectedColorModel() {
            Object val = colormodel.getSelectedItem();
            if (val.equals(UIManager.getString("PDFViewer.export.RGB"))) {
                return PDFParser.RGB;
            } else if (val.equals(UIManager.getString("PDFViewer.export.Gray"))) {
                return PDFParser.GRAYSCALE;
            } else {
                return PDFParser.BLACKANDWHITE;
            }
        }
    }
}
